package com.jiankangyouyi.cloud.basedata.model.excel;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.LinkedHashMap;

/**
 * 食材表Excel对象
 *
 * @author ：wangyalei
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class FoodMaterialExcel implements BaseDataExcel {


    private static final long serialVersionUID = 1L;

    /**
     * 食物ID
     */
    private String foodId;

    /**
     * 食物图片URL
     */
    private String imageUrl;

    /**
     * 食物名称
     */
    private String foodName;

    /**
     * 一级分类名称
     */
    private String classify1Name;

    /**
     * 二级分类名称
     */
    private String classify2Name;

    /**
     * 三级分类名称
     */
    private String classify3Name;
    /**
     * 时令
     */
    private String months;

    /**
     * 地区
     */
    private String countryDistricts;

    /**
     * 禁忌民族
     */
    private String tabooNations;

    /**
     * 食物状态： 启用/禁用/草稿/删除
     */
    private String foodStatus;
    /**
     * 审核状态 0、草稿 1、待审核 2、已审核 3、已驳回
     */
    private String auditStatus;

    /**
     * 是否参与配餐： 是/否
     */
    private String catering;

    /**
     * 配餐版本号
     */
    private String foodVersions;

    /**
     * 被加工食品引用数量
     */
    private String refCount;

    /**
     * 推荐人群，返回示例：糖尿病、肥胖
     */
    private String recommendCrowds;

    /**
     * 禁忌人群，返回示例：糖尿病、肥胖
     */
    private String tabooCrowds;

    /**
     * 致敏原
     */
    private String allergen;

    /**
     * 富含营养素,返回示例：钾、镁
     */
    private String highContentNutrients;

    /**
     * 低量营养素,返回示例：钾、镁
     */
    private String lowContentNutrients;

    /**
     * 升糖指数等级， 高/中/低/未知
     */
    private String giLevel;

    /**
     * 血糖负荷等级， 高/中/低/未知
     */
    private String glLevel;

    /**
     * 嘌呤等级， 高/中/低/未知
     */
    private String purineLevel;

    /**
     * 果糖含量等级， 高/中/低/未知
     */
    private String fructoseLevel;

    /**
     * 性质， 返回示例：产气、家常菜、辛辣刺激
     */
    private String natures;

    /**
     * 膳食特点， 返回示例：全谷物、优质蛋白
     */
    private String foodSpecialties;

    /**
     * 能量，单位 kcal
     */
    private String energy;

    /**
     * 蛋白质，单位 g
     */
    private String protein;

    /**
     * 脂肪，单位 g
     */
    private String fat;

    /**
     * 碳水化合物，单位 g
     */
    private String carbohydrate;

    /**
     * 创建人
     */
    private String createAccount;
    /**
     * 采纳人
     */
    private String adoptAccount;

    /**
     * 创建时间
     */
    private String createTime;
    /**
     * 采纳时间
     */
    private String adoptTime;
    /**
     * 修改人
     */
    private String updateAccount;
    /**
     * 驳回理由
     */
    private String reasonsForRejection;
    /**
     * 更新时间 yyyy-MM-dd HH:mm:ss
     */
    private String updateTime;

    /**
     * Excel头
     */

    public static LinkedHashMap<String, String> HEADER;

    static {
        HEADER = new LinkedHashMap<>();
        HEADER.put("foodId", "食物ID");
        HEADER.put("imageUrl", "食物图片");
        HEADER.put("foodName", "食物名称");
        HEADER.put("classify1Name", "一级分类");
        HEADER.put("classify2Name", "二级分类");
        HEADER.put("classify3Name", "三级分类");
        HEADER.put("months", "时令");
        HEADER.put("countryDistricts", "地区");
        HEADER.put("tabooNations", "禁忌民族");
        HEADER.put("foodStatus", "使用状态");
        HEADER.put("auditStatus", "审核状态");
        HEADER.put("refCount", "引用次数");
        HEADER.put("catering", "参与配餐");
        HEADER.put("foodVersions", "配餐版本号");
        HEADER.put("recommendCrowds", "推荐人群");
        HEADER.put("tabooCrowds", "禁忌人群");
        HEADER.put("allergen", "致敏原");
        HEADER.put("highContentNutrients", "富含营养素");
        HEADER.put("lowContentNutrients", "低量营养素");
        HEADER.put("giLevel", "升糖指数");
        HEADER.put("glLevel", "血糖负荷");
        HEADER.put("purineLevel", "嘌呤等级");
        HEADER.put("fructoseLevel", "果糖含量");
        HEADER.put("natures", "性质");
        HEADER.put("foodSpecialties", "膳食特点");
        HEADER.put("energy", "能量/kcal");
        HEADER.put("protein", "蛋白质/g");
        HEADER.put("fat", "脂肪/g");
        HEADER.put("carbohydrate", "碳水化合物");
        HEADER.put("createAccount", "创建人");
        HEADER.put("adoptAccount", "采纳人");
        HEADER.put("createTime", "创建时间");
        HEADER.put("adoptTime", "采纳时间");
        HEADER.put("updateAccount", "修改人");
        HEADER.put("reasonsForRejection", "驳回理由");
        HEADER.put("updateTime", "修改时间");
    }

    @Override
    public LinkedHashMap<String, String> getHeader() {
        return HEADER;
    }
}
