package com.jiankangyouyi.cloud.basedata.model.query;

import com.jiankangyouyi.cloud.basedata.model.dto.manager.food.component.ClassifyQuery;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;

/**
 * 底层库管理-加工食品列表查询对象
 *
 * @author yangsongbo
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ManagerFoodProcessListQuery {

    private static final long serialVersionUID = 1L;

    /**
     * 食物ID
     */
    private String foodId;

    /**
     * 食物名称，模糊匹配,非必输
     */
    private String foodName;

    /**
     * 食物状态： 0 启用 1 禁用 2 草稿,非必输
     */
    private List<String> foodStatus;
    /**
     * 审核状态 0、草稿 1、待审核 2、已审核 3、已驳回
     */
    private List<String> auditStatus;


    /**
     * 分类查询
     */
    private List<ClassifyQuery> classifyQueryList;

    /**
     * 是否参与配餐： true/false,非必输
     */
    private Boolean catering;
    /**
     * 适合餐别 字典大类 02 字典子类 0226
     */
    private List<String> suitableForMeals;
    /**
     * 推荐人群：字典大类02，字典子类0205,非必输
     */
    private List<String> recommendCrowds;

    /**
     * 禁忌人群：字典大类02，字典子类0205,非必输
     */
    private List<String> tabooCrowds;
    /**
     * 推荐人群 是否选择空选项
     */
    @Builder.Default
    private Boolean recommendCrowdsSelectNull = false;
    /**
     * 禁忌人群 是否选择空选项
     */
    @Builder.Default
    private Boolean tabooCrowdsSelectNull = false;

    /**
     * 富含营养素：字典大类02，字典子类0206,非必输
     */
    private List<String> highContentNutrients;

    /**
     * 低量营养素：字典大类02，字典子类0218,非必输
     */
    private List<String> lowContentNutrients;
    /**
     * 致敏原： 字典大类02，字典子类 0234
     */
    private List<String> allergen;


    /**
     * 升糖指数等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知,非必输
     */
    private List<String> giLevel;

    /**
     * 血糖负荷等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知,非必输
     */
    private List<String> glLevel;

    /**
     * 嘌呤等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知,非必输
     */
    private List<String> purineLevel;

    /**
     * 果糖含量等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知,非必输
     */
    private List<String> fructoseLevel;

    /**
     * 性质：字典大类02，字典子类0215,非必输
     */
    private List<String> natures;

    /**
     * 膳食特点：字典大类02，字典子类0214,非必输
     */
    private List<String> foodSpecialties;

    /**
     * 烹饪特点：字典大类02，字典子类0214,非必输
     */
    private List<String> cookingSpecialties;
    /**
     * 口味 字典大类 02 字典子类 0201 , 非必输
     */
    private List<String> tastes;

    /**
     * 主料食物ID
     */
    private String majorFoodId;

    /**
     * 辅料食物ID
     */
    private String minorFoodId;

    /**
     * 创建者账号
     */
    private String createAccount;

    /**
     * 修改开始时间,非必输
     */
    private Date updateBeginTime;

    /**
     * 修改结束时间,非必输
     */
    private Date updateEndTime;

    /**
     * 修改者账号
     */
    private String updateAccount;
    /**
     * 采纳人账号
     */
    private String adoptAccount;

    /**
     * 创建开始时间,yyyy-MM-dd HH:mm:ss
     */
    private Date createBeginTime;

    /**
     * 创建结束时间,yyyy-MM-dd HH:mm:ss
     */
    private Date createEndTime;
    /**
     * 采纳开始时间,yyyy-MM-dd HH:mm:ss
     */
    private Date adoptBeginTime;

    /**
     * 采纳结束时间,yyyy-MM-dd HH:mm:ss
     */
    private Date adoptEndTime;

}
