package com.jiankangyouyi.cloud.basedata.model.vo.api.food;

import com.jiankangyouyi.cloud.basedata.api.model.entity.foodv4.component.*;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * @description: 食物营养素信息响应dto
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/7/27 10:19 上午
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class FoodNutrientInfoResponseVO implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 食物id 唯一
     */
    private String foodId;
    /**
     * 食物名称
     */
    private String foodName;

    /**
     * 食物图片
     */
    private String foodImg;

    /**
     * 提供的总能量 kcal
     */
    private Integer totalEnergy;

    /**
     * 每100g包含的能量 kcal
     */
    private Integer energy;

    /**
     * 每100g食物 碳水化合物含量 g
     */
    private BigDecimal carbohydrate;
    /**
     * 每100g食物 蛋白质含量 g
     */
    private BigDecimal protein;
    /**
     * 每100g食物 脂肪含量 g
     */
    private BigDecimal fat;

    /**
     * 碳水化合物热量占比
     */
    private BigDecimal carbohydrateRatio;
    /**
     * 蛋白质含量热量占比
     */
    private BigDecimal proteinRatio;
    /**
     * 脂肪含量占比
     */
    private BigDecimal fatRatio;

    /**
     * 主要组成食材
     */
    private List<FoodConstituteInfo> majorMaterials;

    /**
     * 次要组成材料
     */
    private List<FoodConstituteInfo> minorMaterials;

    /**
     * 烹饪步骤
     */
    private List<CookingStep> cookingSteps;

//    /**
//     * 维生素信息g
//     */
//    private BigDecimal vitamin;
//    /***
//     * 矿物质信息g
//     */
//    private BigDecimal mineral;
//    /**
//     * 氨基酸信息g
//     */
//    private BigDecimal aminoAcid;
//    /**
//     * 脂肪酸信息g
//     */
//    private BigDecimal fattyAcid;
//    /**
//     * 植物化学物信息g
//     */
//    private BigDecimal phytochemical;

    /**
     * 维生素信息
     */
    private Vitamin vitaminInfo;
    /***
     * 矿物质信息
     */
    private Mineral mineralInfo;
    /**
     * 氨基酸信息
     */
    private AminoAcid aminoAcidInfo;
    /**
     * 脂肪酸信息
     */
    private FattyAcid fattyAcidInfo;
    /**
     * 植物化学物信息
     */
    private Phytochemical phytochemicalInfo;

    /**
     * 食物基本组成信息
     */
    private FoodBasicCompositionInfo foodBasicCompositionInfo;

    /**
     * 食物基本组成信息
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class FoodBasicCompositionInfo implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 热量
         */
        private Integer energy;
        /**
         * 蛋白质
         */
        private BigDecimal protein;
        /**
         * 脂肪
         */
        private BigDecimal fat;
        /**
         * 碳水化合物
         */
        private BigDecimal carbohydrate;
        /**
         * 水分
         */
        private BigDecimal water;
        /**
         * 不溶性纤维
         */
        private BigDecimal insolubleFiber;
        /**
         * 可溶性纤维
         */
        private BigDecimal solubilityFiber;
        /**
         * 膳食纤维
         */
        private BigDecimal dietaryFiber;
        /**
         * 胆固醇
         */
        private BigDecimal cholesterol;
        /**
         * 嘌呤
         */
        private BigDecimal purine;
        /**
         * GI 值
         */
        private BigDecimal gi;
        /**
         * 灰分
         */
        private BigDecimal ash;

        /**
         * 可食部
         */
        private Integer edible;
    }


    /**
     * 食物组成信息
     */
    @Data
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor
    public static class FoodConstituteInfo implements Serializable {

        private static final long serialVersionUID = 1L;
        /**
         * 食材id
         */
        private String foodId;

        /**
         * 食材名称
         */
        private String foodName;

        /**
         * 食物图片地址
         */
        private String foodImg;

        /**
         * 克数
         */
        private BigDecimal gram;
    }
}
