package com.jiankangyouyi.cloud.basedata.model.vo.manager.food;

import com.jiankangyouyi.cloud.basedata.api.model.entity.foodv4.component.DietaryPattern;
import com.jiankangyouyi.cloud.basedata.api.model.entity.foodv4.component.FoodComposition;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.List;

/**
 * 底层库管理-加工食品计算结果
 *
 * @author yangsongbo
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ManagerFoodProcessCalculateVO implements Serializable {

    /**
     * 加工食品食物成分
     */
    private FoodComposition composition;

    /**
     * 膳食结构
     */
    private DietaryPattern dietaryPattern;

    /**
     * 富含营养素：字典大类02，字典子类0206
     */
    private List<String> highContentNutrients;

    /**
     * 低量营养素：字典大类02，字典子类0218
     */
    private List<String> lowContentNutrients;

    /**
     * 升糖指数等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.api.enums.food.GiLevelEnum}
     */
    private String giLevel;

    /**
     * 血糖负荷等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.api.enums.food.GlLevelEnum}
     */
    private String glLevel;

    /**
     * 嘌呤等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     * <p>
     * {@link com.jiankangyouyi.cloud.basedata.api.enums.food.PurineLevelEnum}
     */
    private String purineLevel;

    /**
     * 推荐人群：字典大类02，字典子类0205
     */
    private List<String> recommendCrowds;

    /**
     * 禁忌人群：字典大类02，字典子类0205
     */
    private List<String> tabooCrowds;

    /**
     * 禁忌民族
     */
    private List<String> tabooNations;

    /**
     * 性质
     */
    private List<String> natures;

    /**
     * 时令
     */
    private List<String> months;

    /**
     * 膳食特点
     */
    private List<String> foodSpecialties;

    /**
     * 烹饪特点
     */
    private List<String> cookingSpecialties;

    /**
     * 致敏原： 字典大类02，字典子类 0234
     */
    private List<String> allergen;

}
