package com.jiankangyouyi.cloud.basedata.model.vo.manager.food.component;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.jiankangyouyi.cloud.core.util.json.serialize.NumberStripTrailingZerosJsonSerialize;
import com.jiankangyouyi.cloud.core.util.json.serialize.QiniuKeyToUrlJsonSerialize;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 底层库管理-预包装食品列表对象
 *
 * @author yangsongbo
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ManagerFoodPackageListInfo {

    /**
     * 食物ID
     */
    private String foodId;

    /**
     * 食物图片URL
     */
    @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
    private String imageUrl;

    /**
     * 食物名称
     */
    private String foodName;

    /**
     * 一级分类名称
     */
    private String classify1Name;

    /**
     * 二级分类名称
     */
    private String classify2Name;

    /**
     * 三级分类名称
     */
    private String classify3Name;

    /**
     * 食物状态： 0 启用 1 禁用 2 草稿
     */
    private String foodStatus;
    /**
     * 条形码
     */
    private String barCode;

    /**
     * 能量，单位 kcal
     */
    private Integer energy;

    /**
     * 蛋白质，单位 g
     */
    @JsonSerialize(using = NumberStripTrailingZerosJsonSerialize.class)
    private BigDecimal protein;

    /**
     * 脂肪，单位 g
     */
    @JsonSerialize(using = NumberStripTrailingZerosJsonSerialize.class)
    private BigDecimal fat;

    /**
     * 碳水化合物，单位 g
     */
    @JsonSerialize(using = NumberStripTrailingZerosJsonSerialize.class)
    private BigDecimal carbohydrate;

    /**
     * 更新时间
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;
    /**
     * 创建时间
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date createTime;

    /**
     * 审核状态
     */
    private String auditStatus;

    /**
     * 创建人 （账号）
     */
    private String createAccount;
    /**
     * 修改人 （账号）
     */
    private String updateAccount;
    /**
     * 采纳人 （账号）
     */
    private String adoptAccount;
    /**
     * 驳回理由
     */
    private String reasonsForRejection;


    /**
     * 采纳时间
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date adoptTime;

}
