package com.jiankangyouyi.cloud.basedata.model.vo.manager.food.component;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.jiankangyouyi.cloud.core.util.json.serialize.NumberStripTrailingZerosJsonSerialize;
import com.jiankangyouyi.cloud.core.util.json.serialize.QiniuKeyToUrlJsonSerialize;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 底层库管理-加工食品列表对象
 *
 * @author yangsongbo
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ManagerFoodProcessListInfo {

    /**
     * 食物ID
     */
    private String foodId;

    /**
     * 食物图片URL
     */
    @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
    private String imageUrl;

    /**
     * 食物名称
     */
    private String foodName;

    /**
     * 一级分类名称
     */
    private String classify1Name;

    /**
     * 二级分类名称
     */
    private String classify2Name;

    /**
     * 三级分类名称
     */
    private String classify3Name;

    /**
     * 食物状态： 0 启用 1 禁用 2 草稿
     */
    private String foodStatus;

    /**
     * 是否参与配餐： true/false
     */
    private Boolean catering;

    /**
     * 推荐人群，返回示例：[“糖尿病”,”肥胖”]
     */
    private List<String> recommendCrowds;

    /**
     * 适合餐别 名称展示
     */
    private List<String> suitableForMeals;

    /**
     * 节日 名称展示
     */
    private List<String> festivals;

    /**
     * 节气 名称展示
     */
    private List<String> solarTerms;

    /**
     * 配餐版本号 名称展示
     */
    private List<String> versions;

    /**
     * 禁忌人群，返回示例：[“糖尿病”,”肥胖”]
     */
    private List<String> tabooCrowds;

    /**
     * 富含营养素,返回示例：[“钾”,”镁”]
     */
    private List<String> highContentNutrients;

    /**
     * 低量营养素,返回示例：[“钾”,”镁”]
     */
    private List<String> lowContentNutrients;

    /**
     * 致敏原，返回示例：[“芒果”,”苹果”]
     */
    private List<String> allergen;

    /**
     * 升糖指数等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     */
    private String giLevel;

    /**
     * 血糖负荷等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     */
    private String glLevel;

    /**
     * 嘌呤等级， HIGH 高，MIDDLE 中，LOW 低，UNKNOWN 未知
     */
    private String purineLevel;

    /**
     * 性质， 返回示例：[“产气”,”家常菜”,”辛辣刺激”]
     */
    private List<String> natures;

    /**
     * 膳食特点， 返回示例：[“全谷物”,”优质蛋白”]
     */
    private List<String> foodSpecialties;

    /**
     * 烹饪特点， 返回示例：[“干”,”湿”]
     */
    private List<String> cookingSpecialties;

    /**
     * 能量，单位 kcal
     */
    private Integer energy;

    /**
     * 蛋白质，单位 g
     */
    @JsonSerialize(using = NumberStripTrailingZerosJsonSerialize.class)
    private BigDecimal protein;

    /**
     * 脂肪，单位 g
     */
    @JsonSerialize(using = NumberStripTrailingZerosJsonSerialize.class)
    private BigDecimal fat;

    /**
     * 碳水化合物，单位 g
     */
    @JsonSerialize(using = NumberStripTrailingZerosJsonSerialize.class)
    private BigDecimal carbohydrate;

    /**
     * 口味
     */
    private String tastes;

    /**
     * 更新时间
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date updateTime;
    /**
     * 创建时间
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date createTime;

    /**
     * 审核状态
     */
    private String auditStatus;

    /**
     * 创建人 （账号）
     */
    private String createAccount;
    /**
     * 修改人 （账号）
     */
    private String updateAccount;
    /**
     * 采纳人 （账号）
     */
    private String adoptAccount;
    /**
     * 驳回理由
     */
    private String reasonsForRejection;


    /**
     * 采纳时间
     */
    @JsonFormat(
            timezone = "GMT+8",
            pattern = "yyyy-MM-dd HH:mm:ss"
    )
    private Date adoptTime;


}
